@@ -21,17 +21,29 @@ mod helper;
 #[derive(Clone)]
 pub struct Kubectl {
     client: kube::Client,
+    manager: String,
 }
 
 impl Kubectl {
     pub async fn try_default() -> kube::Result<Self> {
-        kube::Client::try_default()
-            .await
-            .map(|client| Self { client })
+        kube::Client::try_default().await.map(|client| Self {
+            client,
+            manager: "default-manager".to_string(),
+        })
     }
 
     pub fn from_config(config: kube::Config) -> kube::Result<Self> {
-        kube::Client::try_from(config).map(|client| Self { client })
+        kube::Client::try_from(config).map(|client| Self {
+            client,
+            manager: "default-manager".to_string(),
+        })
+    }
+
+    pub fn manager(self, manager: &str) -> Self {
+        Self {
+            manager: manager.to_string(),
+            ..self
+        }
     }
 
     pub fn client(&self) -> kube::Client {
@@ -76,7 +88,7 @@ impl Kubectl {
         let pp = self.post_params();
 
         let object = if object.resource_version().is_some() {
-            objects.replace(&name, &pp, &object).await?
+            self.patch(object, objects).await?
         } else {
             objects.create(&pp, &object).await?
         };
@@ -102,7 +114,7 @@ impl Kubectl {
         let pp = self.post_params();
 
         let object = if object.resource_version().is_some() {
-            objects.replace(&name, &pp, &object).await?
+            self.patch(object, objects).await?
         } else {
             objects.create(&pp, &object).await?
         };
@@ -127,13 +139,24 @@ impl Kubectl {
         let pp = self.post_params();
 
         let object = if object.resource_version().is_some() {
-            objects.replace(&name, &pp, &object).await?
+            self.patch(object, objects).await?
         } else {
             objects.create(&pp, &object).await?
         };
 
         Ok(object)
     }
+
+    pub async fn patch<K>(&self, object: K, api: kube::Api<K>) -> kube::Result<K>
+    where
+        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let patch = api::Patch::Apply(&object);
+        api.patch(&name, &self.patch_with_manager(&self.manager), &patch)
+            .await
+    }
 }
 
 impl fmt::Debug for Kubectl {
